@@ -43,6 +43,12 @@ sub EXT_controller : Extend('Ext.app.ViewController') {
             this.configureMenu(session);
 JS
 
+        defaultMenuItemHandler => func ['button'], <<'JS',
+            this.getView().hide();
+
+            if (button.route) this.redirectTo(button.route);
+JS
+
         configureMenu => func ['session'], <<'JS',
 JS
 
@@ -103,7 +109,10 @@ sub EXT_panel : Extend('Ext.ActionSheet') {
 }
 
 sub EXT_item : Extend('Ext.Button') {
-    return { textAlign => 'left', };
+    return {
+        textAlign => 'left',
+        handler   => 'defaultMenuItemHandler',
+    };
 }
 
 # BLOCKS
@@ -143,7 +152,7 @@ sub EXT_profile : Extend('Ext.Panel') {
             {   reference => 'menu-profile',
                 text      => l10n('Profile'),
                 iconCls   => $FAS_USER_ALT,
-                handler   => 'profile',
+                route     => 'profile',
             },
             {   text    => l10n('Sign out'),
                 iconCls => $FAS_SIGN_OUT_ALT,
